@@ -2,7 +2,7 @@
 import os
 from sqlalchemy import Column
 from sqlalchemy.types import Integer, String, DateTime
-from sqlalchemy.sql import func
+from sqlalchemy.sql import functions
 from sqlalchemy.ext.declarative import declarative_base
 
 print(f"Importing {os.path.basename(__file__)}...")
@@ -14,7 +14,9 @@ class Serial(declarative_base()):
     __tablename__ = "serial_scanner"
     id = Column(Integer, primary_key=True)
     serial_number = Column(String(20), unique=True, nullable=False)
-    create_time = Column(DateTime(timezone=True), server_default=func.now())
+    create_time = Column(
+        DateTime(timezone=True), server_default=functions.now()
+    )  # changed from func.now() at pylints complaint.  Not sure if this works
     file_location = Column((String(255)))
 
     def __repr__(self):
