@@ -19,17 +19,17 @@ class LightSpeedCog(commands.Cog):
     @commands.has_role("Shiny")
     async def ls_price_lookup_command(self, context: discord.Interaction, search: str):
         """Look up price in Lightspeed"""
-        # await context.response.defer()
+        await context.response.defer()
         generate_ls_access()
         items = Item.get_item_by_desciption(search)
         if items is None:
-            await context.channel.send("No results")
+            await context.followup.send("No results")
             return
         message_output = ""
         for item in items:
             message_output += f"{item.description} is ${item.prices.item_price[0].amount}\n"
 
-        await context.channel.send(message_output)
+        await context.followup.send(message_output)
 
 
 async def setup(client: commands.Cog):
